@@ -7,11 +7,17 @@ from ._logging import LogLevels, RunwayLogger  # noqa
 
 logging.setLoggerClass(RunwayLogger)
 
-if sys.version_info.minor < 8:
+if sys.version_info < (3, 8):
     # importlib.metadata is standard lib for python>=3.8, use backport
-    from importlib_metadata import PackageNotFoundError, version
+    from importlib_metadata import (  # type: ignore # pylint: disable=E
+        PackageNotFoundError,
+        version,
+    )
 else:
-    from importlib.metadata import PackageNotFoundError, version  # pylint: disable=E
+    from importlib.metadata import (  # type: ignore # pylint: disable=E
+        PackageNotFoundError,
+        version,
+    )
 
 try:
     __version__ = version(__name__)
