@@ -7,11 +7,11 @@ from ._envvars import envvars
 from ._gen_sample import gen_sample
 from ._init import init
 from ._kbenv import kbenv
+from ._new import new
 from ._plan import plan
 from ._preflight import preflight
-from ._run_aws import run_aws
 from ._run_python import run_python
-from ._run_stacker import run_stacker
+from ._schema import schema
 from ._takeoff import takeoff
 from ._taxi import taxi
 from ._test import test
@@ -27,11 +27,11 @@ __all__ = [
     "gen_sample",
     "init",
     "kbenv",
+    "new",
     "plan",
     "preflight",
-    "run_aws",
     "run_python",
-    "run_stacker",
+    "schema",
     "takeoff",
     "taxi",
     "test",
