@@ -1,19 +1,17 @@
 """``runway gen-sample static-angular`` command."""
 import logging
-import sys
-from typing import Any  # pylint: disable=W
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, cast
 
 import click
 
 from ... import options
 from .utils import TEMPLATES, convert_gitignore, copy_sample
 
-if sys.version_info.major > 2:
-    from pathlib import Path  # pylint: disable=E
-else:
-    from pathlib2 import Path  # pylint: disable=E
+if TYPE_CHECKING:
+    from ...._logging import RunwayLogger
 
-LOGGER = logging.getLogger(__name__.replace("._", "."))
+LOGGER = cast("RunwayLogger", logging.getLogger(__name__.replace("._", ".")))
 
 
 @click.command("static-angular", short_help="angular static site (static-angular)")
@@ -21,8 +19,7 @@ LOGGER = logging.getLogger(__name__.replace("._", "."))
 @options.no_color
 @options.verbose
 @click.pass_context
-def static_angular(ctx, **_):
-    # type: (click.Context, Any) -> None
+def static_angular(ctx: click.Context, **_: Any) -> None:
     """Generate a sample static site project using Angular."""
     src = TEMPLATES / "static-angular"
     dest = Path.cwd() / "static-angular"
