@@ -39,10 +39,10 @@ def dot_format(out: TextIO, graph: Graph, name: str = "digraph") -> None:
         name: Name of the graph.
 
     """
-    out.write("digraph %s {\n" % name)
+    out.write(f"digraph {name} {{\n")
     for step, deps in each_step(graph):
         for dep in deps:
-            out.write('  "%s" -> "%s";\n' % (step, dep))
+            out.write(f'  "{step}" -> "{dep}";\n')
 
     out.write("}\n")
 
@@ -89,6 +89,7 @@ class Action(BaseAction):
         force: bool = False,  # pylint: disable=unused-argument
         outline: bool = False,  # pylint: disable=unused-argument
         tail: bool = False,  # pylint: disable=unused-argument
+        upload_disabled: bool = False,  # pylint: disable=unused-argument
         **kwargs: Any,
     ) -> None:
         """Generate the underlying graph and prints it."""
