@@ -2,11 +2,12 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import Union
+from typing import TypeVar, Union
 
 from typing_extensions import TypedDict
 
 AnyPath = Union[Path, str]
+AnyPathConstrained = TypeVar("AnyPathConstrained", Path, str)
 
 
 class Boto3CredentialsTypeDef(TypedDict, total=False):
